@@ -4,9 +4,12 @@ Data models for the CPython limited API and stable ABI.
 
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Literal, Union
 
+# a best-effort taxonomy for shared object file symbols across all platforms.
+Visibility = Literal["local", "global", "weak"]
+
 
 @dataclass(frozen=True, eq=False, unsafe_hash=True)
 class Symbol:
@@ -24,6 +27,11 @@ class Symbol:
     The symbol's underlying name. This may not correspond to an actual symbol
     in a binary without platform-specific normalization.
     """
+    visibility: Visibility | None = field(default=None, hash=False)
+    """
+    The symbol's visibility in the shared object file, or None if it could not
+    be determined.
+    """
 
     @property
     def macos(self) -> str:
